package dk.nsp.api.auth

sealed class AuthException(errorString: String) : Exception(errorString) {
    object NoRefreshTokenError : AuthException("No refresh token")
    data class UnknownError(val optionalInfo: String? = null) :
        AuthException(optionalInfo ?: "Something unexpected happened")

    object FailedEncryption : AuthException("Could not encrypt via the given key and data")
    object MissingKeyIdInStorage : AuthException("The KeyId was not stored on the device")
    object MissingRefreshTokenInStorage : AuthException("No refresh token stored on device")
    object BadKeyOrEncryption :
        AuthException("Could not decrypt refresh token (Probably broken or corrupted)")

    object NoUsableBrowserFoundException : AuthException("No valid browser found")
}