package dk.nsp.api.auth.keyserver

import dk.nsp.api.auth.keyserver.models.KeyModelDTO
import retrofit2.http.GET
import retrofit2.http.Query


interface KeyServerApi {
    /**
     * Gets a [KeyModelDTO] via a given [secret] and [keyId] if they match
     * @param secret String
     * @param keyId String
     * @return [KeyModelDTO]
     */
    @GET("/keyservice/key")
    suspend fun getKey(
        @Query("secret") secret: String,
        @Query("keyid") keyId: String
    ): KeyModelDTO

    /**
     * Gets a [KeyModelDTO] via the given [keyId] and [longsecret] if they match
     * @param longsecret String
     * @param keyId String
     * @return [KeyModelDTO]
     */
    @GET("/keyservice/longkey")
    suspend fun getKeyViaLongSecret(
        @Query("longsecret") longsecret: String,
        @Query("keyid") keyId: String
    ): KeyModelDTO

    /**
     * Creates a new key
     * @param secret  String
     * @return [KeyModelDTO]
     */
    @GET("/keyservice/createkey")
    suspend fun createKey(@Query("secret") secret: String): KeyModelDTO
}