package dk.nsp.api.auth.keyserver

import dk.nsp.api.auth.keyserver.models.KeyModelDTO
import dk.nsp.api.util.CustomOkHttpClient
import dk.nsp.api.util.converters.JsonConfig
import dk.nsp.mingraviditet.api.BuildConfig
import dk.nsp.shared.ResultWrapper
import dk.nsp.shared.tryOrFailed
import retrofit2.Retrofit

class KeyServerController(private val keyServerApi: KeyServerApi) : IKeyServerController {
    override suspend fun createKey(secret: String): ResultWrapper<KeyModelDTO> {
        return tryOrFailed {
            keyServerApi.createKey(secret)
        }
    }

    override suspend fun getKey(password: String, keyId: String): ResultWrapper<KeyModelDTO> {
        return tryOrFailed {
            keyServerApi.getKey(password, keyId)
        }
    }

    override suspend fun getKeyViaLongSecret(
        longSecret: String,
        keyId: String
    ): ResultWrapper<KeyModelDTO> {
        return tryOrFailed {
            keyServerApi.getKeyViaLongSecret(longSecret, keyId)
        }
    }

    companion object {
        private var instance: KeyServerController? = null

        fun get(): KeyServerController {
            return instance
                ?: KeyServerController(
                    Retrofit.Builder()
                        .baseUrl(BuildConfig.KeyCloakServer)
                        .addConverterFactory(JsonConfig.converterFactory)
                        .client(CustomOkHttpClient.getClientWithoutAuth())
                        .build()
                        .create(KeyServerApi::class.java)
                ).apply {
                    instance = this
                }
        }
    }
}