package dk.nsp.api.careplan

import dk.nsp.api.careplan.models.*
import dk.nsp.api.util.extensions.asyncIO
import dk.nsp.shared.ResultWrapper
import dk.nsp.shared.Success
import kotlinx.coroutines.CoroutineScope
import kotlinx.coroutines.Deferred
import org.joda.time.DateTime

class CareplanControllerMock : ICareplanController {
    // In this mock we assume that we are 4 weeks pregnant
    private val firstDateOfCareplan = DateTime().minusWeeks(4)

    private val defaultHealthcareProfessional = HealthcareProfessionalDTO(
        null,
        "Louise",
        "Hansen",
        "Regionshospitalet Horsens",
        "12345678",
        "LouiseHansen@rh-horsens.dk",
        null
    )
    private val defaultHealthcareLocation = HealthcareLocationDTO(
        null,
        AddressDTO("Sundvej 30", "8700", "Horsens"),
        "Regionshospitalet Horsens",
        "7842 5000",
        null,
        null
    )

    private val observations = listOf(
        ObservationDTO(
            DateTime().minusWeeks(1),
            listOf(MeasurementDTO("65", "kg", "Vægt")),
            "Sygeplejerske",
            "Peter Hansen",
            true,
            "Mor",
            ObservationTypeDTO.Weight,
            "measurementId"
        )
    )

    private val activities = listOf(
        CareplanActivityDTO(
            defaultHealthcareProfessional,
            defaultHealthcareLocation,
            "6+0",
            CareplanActivityPlannedTimeDTO(
                firstDateOfCareplan.plusWeeks(6).withTime(10, 0, 0, 0),
                firstDateOfCareplan.plusWeeks(6).withTime(11, 0, 0, 0)
            ),
            CareplanStatusDTO.Planned,
            "Scanning",
            "Her vil det være muligt at se en lille ært måske",
            null,
            null,
            null,
            "Første scanning",
            "firstScanId",
            null,
            observations,
            firstDateOfCareplan.plusWeeks(6)
        ),
        CareplanActivityDTO(
            null,
            null,
            "12+0",
            null,
            CareplanStatusDTO.Expected,
            "12 ugers scanning",
            null,
            null,
            null,
            null,
            null,
            "12weekId",
            null,
            null,
            firstDateOfCareplan.plusWeeks(12)
        )
    )

    override fun getCareplan(scope: CoroutineScope): Deferred<ResultWrapper<List<CareplanDTO>>> =
        scope.asyncIO {
            Success(
                listOf(
                    CareplanDTO(
                        "Patient",
                        activities,
                        null,
                        "Første barn",
                        "Her er der en beskrivelse på første barn",
                        null,
                        OrganizationDTO("orgId", "sor"),
                        "CareplanId",
                        1
                    )
                )
            )
        }
}