/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2018 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

@file:UseSerializers(DateTimeSerializer::class)

package dk.nsp.api.careplan.models

import dk.nsp.api.util.converters.DateTimeSerializer
import kotlinx.serialization.Serializable
import kotlinx.serialization.UseSerializers
import org.joda.time.DateTime

@Serializable
data class CareplanActivityDTO(
    val practitioner: HealthcareProfessionalDTO?,
    val location: HealthcareLocationDTO?,
    val gestationWeek: String, //pattern: ^[1-9]?[0-9]\+[0-6]$
    val plannedTime: CareplanActivityPlannedTimeDTO?,
    val status: CareplanStatusDTO,
    val title: String,
    val description: String?,
    val reference: String?, //A pointer to whatever object this activity is related to
    val goal: CareplanGoalDTO?,
    val code: CodeDTO?,
    val kind: String?,
    val id: String, //UUID
    val notes: List<NoteDTO>?,
    val observations: List<ObservationDTO>?,
    val sortDate: DateTime
)