/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package dk.nsp.api.datacard

import dk.nsp.api.datacard.models.*
import dk.nsp.api.util.extensions.asyncIO
import dk.nsp.shared.ResultWrapper
import dk.nsp.shared.Success
import kotlinx.coroutines.CoroutineScope
import kotlinx.coroutines.Deferred
import org.joda.time.DateTime

class DataCardControllerMock : IDataCardController {
    override fun getMaternityDataCard(scope: CoroutineScope): Deferred<ResultWrapper<List<MaternityDataCardDTO>>> =
        scope.asyncIO {
            Success(
                listOf(
                    MaternityDataCardDTO(
                        modifiedTime = DateTime(),
                        author = HealthCareActorDTO.HealthCareProfessionalDTO(
                            PersonNameDTO(
                                listOf("Hans"),
                                listOf(),
                                "Hansen"
                            )
                        ),
                        recordTarget = CprIdentifiedPersonDTO(
                            PersonNameDTO(
                                listOf(
                                    "Maja",
                                    "Ingrid"
                                ), listOf(), "Petersen"
                            ), "0101010102"
                        ),
                        childPartnerSection = ChildPartnerSectionDTO(
                            DateTime(),
                            null,
                            PersonNameDTO(listOf("Jens"), listOf(), "Petersen"),
                            "0101010101"
                        ),
                        languageSection = null,
                        bodyMeasuresSection = null,
                        socialHistorySection = null,
                        previousBirthsSection = null,
                        previousAbortionsSection = null,
                        expectedDateOfDeliverySection = ExpectedDateOfDeliverySectionDTO(
                            DateTime(),
                            null,
                            ExpectedDateOfDeliveryFromLastPeriodDTO(
                                DateTime().minusMonths(1),
                                DurationDTO.DurationInDaysDTO(20, "dage"),
                                DateTime().plusMonths(8),
                                ExpectedDateOfDeliveryCertaintyDTO.Certain
                            ),
                            null,
                            null,
                            1,
                            1.0,
                            "No remarks..."
                        ),
                        prenatalRiskAssessmentSection = null,
                        workEnvironmentImpactSection = null,
                        allergiesSection = AllergiesSectionDTO(
                            DateTime(),
                            null,
                            "Nødder, morfin, skaldyr",
                            AllergicPredispositionOfChildDTO.DoublePredisposition
                        ),
                        screeningsSection = null,
                        chronicDiseasesSection = null,
                        medicineSection = null,
                        mmrVaccinationSection = null,
                        historyOfPreviousTreatmentWithImpactOnPregnancySection = null,
                        tobaccoUseAndExposureSection = null,
                        alcoholDrinkingBehaviorSection = null,
                        assistedFertilizationSection = null,
                        substanceUseSection = null,
                        dietaryAndExerciseSection = null,
                        healthInsuranceSection = null,
                        birthPlaceSection = null,
                        midwifeClinicSection = null,
                        postpartumNursingSection = null,
                        overallAssessmentSection = OverallAssessmentSectionDTO(
                            DateTime(),
                            null,
                            PrenatalCareAssessmentDTO(
                                "I sidste graviditet præeklampsi, men kontrolleret bagefter og har normal BT. Dårlig fødselsoplevelse efter akut sectio sidst. Overvejer sectio denne fødsel. Faderen arbejder delvist i udlandet så er meget alene, men har godt netværk.",
                                "Here are countless ways you can turn your grilling not only into. Without a doubt there is something very.",
                                null,
                                CareLevelDTO.Basic
                            ),
                            ObstetricAssessmentDTO(YesNoEnumDTO.Yes, "Det er der bare behov for"),
                            SocialServicesPerinatalCareAssessmentDTO(
                                YesNoEnumDTO.Yes,
                            )
                        ),
                        personalDataSection = null,
                        healthCareSection = null,
                        episodeOfCareIdentifier = "episodeOfCareIdentifier",
                        "Identifier"
                    )
                )
            )
        }
}