/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
@file:UseSerializers(DateTimeSerializer::class)

package dk.nsp.api.datacard.models

import dk.nsp.api.util.converters.DateTimeSerializer
import kotlinx.serialization.SerialName
import kotlinx.serialization.Serializable
import kotlinx.serialization.UseSerializers
import org.joda.time.DateTime

@Serializable
data class BirthDTO(
    val children: List<ChildDTO>?,
    val date: DateTime?,
    val gestationLength: DurationDTO.DurationInDaysDTO?,
    val birthPlace: String?,
    val pregnancySummary: String?,
    val birthSummary: String?,
    val subjectiveBirthExperience: SubjectiveBirthExperienceDTO?,
    val puerperalSepsis: Boolean?,
)

@Serializable
data class ChildDTO(
    val sex: SexDTO?,
    val birthWeight: BodyMeasureValueDTO?,
    val outcome: BirthOutcomeDTO? = null,
    val childsCurrentHealthStatus: String?
)

@Serializable
enum class SubjectiveBirthExperienceDTO {
    @SerialName("good")
    Good,

    @SerialName("normal")
    Normal,

    @SerialName("bad")
    Bad,

}

@Serializable
enum class SexDTO {
    @SerialName("female")
    Female,
    @SerialName("male")
    Male
}

@Serializable
enum class BirthOutcomeDTO {
    @SerialName("livebirth")
    Livebirth,
    @SerialName("stillbirth")
    Stillbirth
}