/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package dk.nsp.api.datacard.models

import kotlinx.serialization.DeserializationStrategy
import kotlinx.serialization.ExperimentalSerializationApi
import kotlinx.serialization.Serializable
import kotlinx.serialization.Serializer
import kotlinx.serialization.json.JsonContentPolymorphicSerializer
import kotlinx.serialization.json.JsonElement
import kotlinx.serialization.json.jsonObject
import kotlinx.serialization.json.jsonPrimitive
import timber.log.Timber

@ExperimentalSerializationApi
@Serializer(forClass = HealthCareActorDTO::class)
object HealthCareActorSerializer :
    JsonContentPolymorphicSerializer<HealthCareActorDTO>(HealthCareActorDTO::class) {
    override fun selectDeserializer(element: JsonElement): DeserializationStrategy<out HealthCareActorDTO> {
        return when (element.jsonObject["objectType"]?.jsonPrimitive?.content) {
            "HealthCareOrganization" -> HealthCareActorDTO.HealthCareOrganizationDTO.serializer()
            "HealthCareProfessional" -> HealthCareActorDTO.HealthCareProfessionalDTO.serializer()
            else -> {
                Timber.e("No object type for: $element")
                TODO()
            }
        }
    }
}

@Serializable(with = HealthCareActorSerializer::class)
sealed class HealthCareActorDTO {
    @Serializable
    data class HealthCareProfessionalDTO(
        val name: PersonNameDTO,
    ) : HealthCareActorDTO()

    @Serializable
    data class HealthCareOrganizationDTO(
        val name: String,
    ) : HealthCareActorDTO()
}


