package dk.nsp.api.util

import dk.nsp.api.auth.AuthController
import dk.nsp.mingraviditet.api.BuildConfig
import dk.nsp.shared.Failed
import dk.nsp.shared.Success
import kotlinx.coroutines.runBlocking
import okhttp3.Interceptor
import okhttp3.Request
import okhttp3.Response
import timber.log.Timber


class AuthInterceptor(private val authController: AuthController) : Interceptor {

    private val authHeaderKey = "Authorization"
    private val androidVersionHeaderKey = "android-version"
    private val authType = "Bearer"

    override fun intercept(chain: Interceptor.Chain): Response {
        return attachAuthToken(chain)
    }

    private fun attachAuthToken(chain: Interceptor.Chain): Response {
        val token = getTokenBlocking()
        val builder = chain.request().newBuilder()

        builder.setHeader(androidVersionHeaderKey, BuildConfig.ANDROID_APP_VERSION_NAME)
        builder.setHeader(authHeaderKey, "$authType $token")

        return chain.proceed(builder.build())
    }

    private fun getTokenBlocking(): String? = runBlocking {
        if (!authController.isLoggedIn()) {
            Timber.e("User is not logged in")
            null
        } else {
            when (val accessToken = authController.getAccessToken()) {
                is Success -> accessToken.value
                is Failed -> {
                    Timber.e(accessToken.error, "Could not get access token")
                    null
                }
            }
        }
    }

    private fun Request.Builder.setHeader(headerKey: String, value: String) {
        removeHeader(headerKey)
        addHeader(headerKey, value)
    }
}