package dk.nsp.api.util

import dk.nsp.api.auth.AuthController
import dk.nsp.mingraviditet.api.BuildConfig
import okhttp3.ConnectionSpec
import okhttp3.OkHttpClient
import okhttp3.logging.HttpLoggingInterceptor
import java.util.concurrent.TimeUnit

object CustomOkHttpClient {
    private fun createDefaultBuilder(): OkHttpClient.Builder {
        val builder = OkHttpClient.Builder()
            .connectTimeout(1, TimeUnit.MINUTES)
            .writeTimeout(1, TimeUnit.MINUTES)
            .readTimeout(30, TimeUnit.SECONDS)

        //force https
        builder.connectionSpecs(listOf(ConnectionSpec.MODERN_TLS))
        // Check if we should enable logging of all network to console
        if (BuildConfig.AllowLogNetwork) {
            builder.addNetworkInterceptor(
                HttpLoggingInterceptor().apply {
                    level = HttpLoggingInterceptor.Level.BODY
                }
            )
        }

        return builder
    }

    private var secureClientWithAuth: OkHttpClient? = null
    fun getSecureClientWithAuth(authController: AuthController): OkHttpClient {
        return secureClientWithAuth
            ?: createDefaultBuilder()
                .addInterceptor(
                    AuthInterceptor(authController)
                )
                .build()
                .apply {
                    secureClientWithAuth = this
                }
    }


    private var defaultClientWithoutAuth: OkHttpClient? = null
    fun getClientWithoutAuth(): OkHttpClient {
        return createDefaultBuilder()
            .build().apply {
                defaultClientWithoutAuth = this
            }
    }
}