package dk.nsp.api.util

import net.openid.appauth.AuthorizationException
import retrofit2.HttpException


inline class ThrowableNetworkErrorsApi(val throwable: Throwable)

inline val Throwable.networkErrorsApi: ThrowableNetworkErrorsApi
    get() = ThrowableNetworkErrorsApi(this)


fun ThrowableNetworkErrorsApi.isHttpErrorWithCode(code: Int): Boolean {
    val asHttpException = throwable as? HttpException
    return asHttpException?.code() == code
}

fun ThrowableNetworkErrorsApi.isRefreshTokenExpired(): Boolean {
    return throwable is AuthorizationException &&
            throwable.isRefreshTokenExpired() //HMM ??
}

/**
 * Checks if an authorization exception was due to an expired refresh token.
 * @receiver AuthorizationException
 * @return Boolean true if refresh token is expired
 */
fun AuthorizationException.isRefreshTokenExpired(): Boolean =
    errorDescription?.contains("refresh token expired", true) == true ||
            error?.contains("invalid_grant", true) == true