package dk.nsp.mingraviditet.extensions

import android.view.View
import android.view.ViewGroup
import androidx.annotation.UiThread
import androidx.core.view.children
import androidx.databinding.BindingAdapter


//region general Visibility toggles
@BindingAdapter("goneOnNull")
fun View.goneOnNull(value: Any?) {
    visibility = when (value) {
        null -> View.GONE
        else -> View.VISIBLE
    }
}

@BindingAdapter("goneOnTrue")
fun View.goneOnTrue(value: Boolean?) {
    visibility = when (value) {
        true -> View.GONE
        else -> View.VISIBLE
    }
}

@BindingAdapter("goneOnFalse")
fun View.goneOnFalse(value: Boolean?) {
    visibility = when (value) {
        true -> View.VISIBLE
        else -> View.GONE
    }
}

@BindingAdapter("visibleOnTrue")
fun View.visibleOnTrue(value: Boolean?) {
    visibility = when (value) {
        true -> View.VISIBLE
        else -> View.GONE
    }
}

@BindingAdapter("goneOnBlank")
fun View.goneOnBlank(text: String?) {
    visibility = when (text?.isNotBlank()) {
        true -> View.VISIBLE
        else -> View.GONE
    }
}
//endregion


/**
 * Disables the view (isEnabled = false, isClickable = false)
 * if it is a ViewGroup, then all children will be disabled as well
 * (From https://github.com/Tvede-dk/CommonsenseAndroidKotlin/blob/master/widgets/src/main/kotlin/com/commonsense/android/kotlin/views/extensions/ViewExtensions.kt)
 * @receiver View
 */
@UiThread
fun View.disable() {
    isEnabled = false
    (this as? ViewGroup)?.children?.forEach(View::disable)
}

/**
 * Enables this view (isEnabled = true, isClickable = true)
 * if it is a ViewGroup, then all children will be enabled as well
 * (From https://github.com/Tvede-dk/CommonsenseAndroidKotlin/blob/master/widgets/src/main/kotlin/com/commonsense/android/kotlin/views/extensions/ViewExtensions.kt)
 * @receiver View
 */
@UiThread
fun View.enable() {
    isEnabled = true
    (this as? ViewGroup)?.children?.forEach(View::enable)
}

@UiThread
fun ViewGroup.enabledOrDisabled(enabled: Boolean) {
    if (enabled) {
        enable()
    } else {
        disable()
    }
}