package dk.nsp.mingraviditet.ui.main

import android.os.Bundle
import android.view.LayoutInflater
import androidx.annotation.IdRes
import androidx.core.content.ContextCompat
import androidx.lifecycle.LiveData
import androidx.navigation.NavController
import com.google.android.material.bottomnavigation.BottomNavigationView
import dagger.hilt.android.AndroidEntryPoint
import dk.nsp.mingraviditet.R
import dk.nsp.mingraviditet.databinding.ActivityMainBinding
import dk.nsp.mingraviditet.ui.BaseActivity
import dk.nsp.mingraviditet.util.extensions.setupWithNavController

@AndroidEntryPoint
class MainActivity : BaseActivity() {
    private var currentNavController: LiveData<NavController>? = null

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        val binding = ActivityMainBinding.inflate(LayoutInflater.from(this))
        setContentView(binding.root)

        if (savedInstanceState == null) {
            setupBottomNavigationBar()
        } // else, need to wait for onRestoreInstanceState

//        setBadge(binding.bottomBar, R.id.appointments, 1)
    }

    private fun setBadge(bottomNav: BottomNavigationView, @IdRes menu: Int, number: Int) {
        if (number == 0) {
            bottomNav.getBadge(menu).apply {
                this?.isVisible = false
                this?.clearNumber()
            }
        } else {
            bottomNav.getOrCreateBadge(menu).apply {
                isVisible = true
                this.number = number
                this.badgeTextColor = ContextCompat.getColor(baseContext, R.color.white)
            }
        }
    }

    override fun onRestoreInstanceState(savedInstanceState: Bundle) {
        super.onRestoreInstanceState(savedInstanceState)
        // Now that BottomNavigationBar has restored its instance state
        // and its selectedItemId, we can proceed with setting up the
        // BottomNavigationBar with Navigation
        setupBottomNavigationBar()
    }

    private fun setupBottomNavigationBar() {
        val bottomNavigationView = findViewById<BottomNavigationView>(R.id.bottom_bar)

        val navGraphIds = listOf(
            R.navigation.nav_overview,
            R.navigation.nav_knowledge,
            R.navigation.nav_appointments,
            R.navigation.nav_journal,
            R.navigation.nav_more
        )

        val controller = bottomNavigationView.setupWithNavController(
            navGraphIds = navGraphIds,
            fragmentManager = supportFragmentManager,
            containerId = R.id.nav_host_fragment,
            intent = intent
        )

        // Whenever the selected controller changes, setup the action bar
        controller.observe(this, { navController ->
            // TODO Remove This is just for testing this out
            setBadge(bottomNavigationView, navController.graph.id, 0)
        })
        currentNavController = controller
    }

    override fun onSupportNavigateUp(): Boolean {
        return currentNavController?.value?.navigateUp() ?: false
    }
}