/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package dk.nsp.mingraviditet.ui.main.appointments.details

import androidx.lifecycle.LiveData
import androidx.lifecycle.MutableLiveData
import androidx.lifecycle.ViewModel
import dk.nsp.domain.careplan.CareplanActivity
import dk.nsp.domain.careplan.CareplanStatus
import dk.nsp.mingraviditet.util.extensions.postSingleEvent
import dk.nsp.mingraviditet.util.livedata.SingleEvent

class CareplanActivityDetailsViewModel constructor(
        val careplanActivity: CareplanActivity
) : ViewModel() {

    fun showMap(): Boolean {
        return careplanActivity.status == CareplanStatus.Planned && careplanActivity.location != null
    }

    private val _onEmailClicked: MutableLiveData<SingleEvent<String>> = MutableLiveData()
    val onEmailClicked: LiveData<SingleEvent<String>> = _onEmailClicked
    fun onEmailClicked() {
        careplanActivity.location?.email?.let {
            _onEmailClicked.postSingleEvent(it)
        }
    }

    private val _onPhoneClicked: MutableLiveData<SingleEvent<String>> = MutableLiveData()
    val onPhoneClicked: LiveData<SingleEvent<String>> = _onPhoneClicked
    fun onPhoneClicked() {
        careplanActivity.location?.phone?.let {
            _onPhoneClicked.postSingleEvent(it)
        }
    }

    private val _onNavigateClicked: MutableLiveData<SingleEvent<String>> = MutableLiveData()
    val onNavigateClicked: LiveData<SingleEvent<String>> = _onNavigateClicked
    fun onNavigateClicked() {
        careplanActivity.location?.address?.toString()?.let {
            _onNavigateClicked.postSingleEvent(it)
        }
    }

}