package dk.nsp.mingraviditet.ui.main.appointments.rows

import android.content.res.ColorStateList
import dk.nsp.domain.careplan.CareplanActivity
import dk.nsp.mingraviditet.R
import dk.nsp.mingraviditet.databinding.AppointmentRowBinding
import dk.nsp.mingraviditet.ui.main.appointments.getDateString
import dk.nsp.mingraviditet.util.android.recycler.BindingViewHolder
import dk.nsp.mingraviditet.util.android.recycler.DelegationListAdapterInflater
import dk.nsp.mingraviditet.util.android.recycler.RecyclerAdapterView
import dk.nsp.mingraviditet.util.extensions.getColorFromAttr
import dk.nsp.mingraviditet.util.extensions.toLongFormat
import dk.nsp.util.TextModel

data class AppointmentRowBindingModel(val activity: CareplanActivity, val onClick: () -> Unit) {
    fun getSubtitleText(): TextModel {
        return if (activity.plannedTime != null) {
            TextModel.from(activity.sortDate.toLongFormat())
        } else {
            activity.getDateString()
        }
    }
}

class AppointmentRow(val model: AppointmentRowBindingModel) :
        RecyclerAdapterView<AppointmentRowBinding> {
    override fun bindData(viewHolder: BindingViewHolder<AppointmentRowBinding>) {
        val ctx = viewHolder.binding.root.context
        viewHolder.binding.bindingModel = model

        if (model.activity.sortDate.isBeforeNow) {
            val pastBackgroundColor = ctx.getColorFromAttr(R.attr.pastTimelineBackgroundColor)
            viewHolder.binding.root.setBackgroundColor(pastBackgroundColor)
            viewHolder.binding.verticalTimeline.backgroundTintList =
                    ColorStateList.valueOf(ctx.getColorFromAttr(R.attr.pastTimelineColor))
        } else {
            val backgroundColor = ctx.getColorFromAttr(R.attr.backgroundColor)
            viewHolder.binding.root.setBackgroundColor(backgroundColor)

            viewHolder.binding.verticalTimeline.backgroundTintList =
                ColorStateList.valueOf(ctx.getColorFromAttr(R.attr.futureTimelineColor))
        }
    }

    override val createHolderFunction: DelegationListAdapterInflater<AppointmentRowBinding> =
            AppointmentRowBinding::inflate


}