package dk.nsp.mingraviditet.ui.main.appointments.rows

import android.content.res.ColorStateList
import dk.nsp.mingraviditet.R
import dk.nsp.mingraviditet.databinding.AppointmentsYearDividerRowBinding
import dk.nsp.mingraviditet.util.android.recycler.BindingViewHolder
import dk.nsp.mingraviditet.util.android.recycler.DelegationListAdapterInflater
import dk.nsp.mingraviditet.util.android.recycler.RecyclerAdapterView
import dk.nsp.mingraviditet.util.extensions.getColorFromAttr

class AppointmentsYearRow(val year: String, val isPast: Boolean) :
    RecyclerAdapterView<AppointmentsYearDividerRowBinding> {
    override fun bindData(viewHolder: BindingViewHolder<AppointmentsYearDividerRowBinding>) {
        val ctx = viewHolder.binding.root.context

        viewHolder.binding.year = year

        val backgroundColor = if (isPast) {
            ctx.getColorFromAttr(R.attr.pastTimelineBackgroundColor)
        } else {
            ctx.getColorFromAttr(R.attr.backgroundColor)
        }
        viewHolder.binding.root.setBackgroundColor(backgroundColor)

        if (isPast) {
            val pastTimelineColor = ctx.getColorFromAttr(R.attr.pastTimelineColor)
            val pastColorState =
                    ColorStateList.valueOf(pastTimelineColor)
            viewHolder.binding.verticalTimeline.backgroundTintList = pastColorState
            viewHolder.binding.horizontalDivider.backgroundTintList = pastColorState
            viewHolder.binding.yearText.setTextColor(pastTimelineColor)
        } else {
            val currentColorState =
                ColorStateList.valueOf(ctx.getColorFromAttr(R.attr.futureTimelineColor))
            viewHolder.binding.verticalTimeline.backgroundTintList = currentColorState
            viewHolder.binding.horizontalDivider.backgroundTintList = currentColorState
            viewHolder.binding.yearText.setTextColor(ctx.getColorFromAttr(R.attr.mgTextColor))
        }
    }

    override val createHolderFunction: DelegationListAdapterInflater<AppointmentsYearDividerRowBinding> =
        AppointmentsYearDividerRowBinding::inflate
}