package dk.nsp.mingraviditet.ui.main.journal

import android.os.Bundle
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.constraintlayout.motion.widget.MotionLayout
import androidx.fragment.app.Fragment
import androidx.fragment.app.viewModels
import androidx.navigation.fragment.findNavController
import dagger.hilt.android.AndroidEntryPoint
import dk.nsp.mingraviditet.R
import dk.nsp.mingraviditet.databinding.FragmentJournalBinding
import dk.nsp.mingraviditet.ui.widgets.BottomInfoToggler
import dk.nsp.mingraviditet.util.android.motionlayout.MotionLayoutStateEnum
import dk.nsp.mingraviditet.util.android.recycler.DelegatingListAdapter
import dk.nsp.mingraviditet.util.extensions.handleToolbarState
import dk.nsp.mingraviditet.util.extensions.navigateSafe
import dk.nsp.mingraviditet.util.extensions.observeIfNotHandled
import dk.nsp.mingraviditet.util.extensions.setupToolbarStateListener

@AndroidEntryPoint
class JournalFragment : Fragment() {
    private lateinit var binding: FragmentJournalBinding

    private val adapter by lazy {
        DelegatingListAdapter()
    }

    private val journalViewModel: JournalViewModel by viewModels()

    private var state: MotionLayoutStateEnum = MotionLayoutStateEnum.Start
        set(value) {
            field = value
            (binding.root as MotionLayout).handleToolbarState(value)
        }

    private var infoToggler: BottomInfoToggler? = null

    override fun onCreateView(
        inflater: LayoutInflater,
        container: ViewGroup?,
        savedInstanceState: Bundle?
    ): View {
        binding = FragmentJournalBinding.inflate(inflater, null, false)
        binding.toolbarTitle.setText(R.string.bottom_navigation_title_journal)
        binding.recyclerview.adapter = adapter

        setupToolbarState()

        infoToggler = BottomInfoToggler(binding.bottomInfo, binding.recyclerview)

        journalViewModel.sectionCards.observe(viewLifecycleOwner) {
            adapter.submitList(it)
        }

        journalViewModel.onNavigateToSection.observeIfNotHandled(viewLifecycleOwner) {
            when (it) {
                JournalSection.Screenings,
                JournalSection.AroundThePregnancy,
                JournalSection.HealthCare,
                JournalSection.PersonalData -> {
                    findNavController().navigateSafe(
                        JournalFragmentDirections.actionJournalFragmentToJournalSectionOverviewFragment(
                            it
                        )
                    )
                }
                JournalSection.OverallAssessment -> {
                    findNavController().navigateSafe(JournalFragmentDirections.actionJournalFragmentToJournalOverallAssessmentFragment())
                }
                JournalSection.JournalNotes -> {
                    findNavController().navigateSafe(JournalFragmentDirections.actionJournalFragmentToJournalNotesFragment())
                }
                JournalSection.Scans -> {
                    findNavController().navigateSafe(JournalFragmentDirections.actionJournalFragmentToJournalScansFragment())
                }
                JournalSection.Measurements -> {
                    findNavController().navigateSafe(JournalFragmentDirections.actionJournalFragmentToJournalMeasurementsFragment())
                }
            }
        }

        return binding.root
    }

    private fun setupToolbarState() {
        setupToolbarStateListener(binding.root) { newState ->
            state = newState
        }

        (binding.root as MotionLayout).handleToolbarState(state)
    }
}