/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package dk.nsp.mingraviditet.ui.main.journal.sections.notes

import androidx.hilt.Assisted
import androidx.hilt.lifecycle.ViewModelInject
import androidx.lifecycle.*
import dk.nsp.domain.careplan.Note
import dk.nsp.domain.repository.NotesRepository
import dk.nsp.mingraviditet.ui.adapterviews.DetailsHeaderRow
import dk.nsp.mingraviditet.ui.main.journal.JournalSection
import dk.nsp.mingraviditet.ui.widgets.HeaderViewWithIconBindingModel
import dk.nsp.mingraviditet.util.android.recycler.RecyclerAdapterView
import dk.nsp.mingraviditet.util.extensions.transform
import dk.nsp.shared.Failed
import dk.nsp.shared.Success
import dk.nsp.shared.util.launchDefault

class JournalNotesViewModel @ViewModelInject constructor(
    private val notesRepository: NotesRepository,
    @Assisted private val savedStateHandle: SavedStateHandle
) : ViewModel() {

    private val _notes: MutableLiveData<List<Note>> = MutableLiveData()
    val rowsToShow: LiveData<List<RecyclerAdapterView<*>>> = _notes.transform {
        createRows(it)
    }

    init {
        viewModelScope.launchDefault {
            val notesRes = notesRepository.getNotes(viewModelScope).await()

            when (notesRes) {
                is Success -> {
                    // TODO Make notes to expandable cards
                    _notes.postValue(notesRes.value)
                }
                is Failed -> {
                    // Empty state
                }
            }
        }
    }

    private fun createRows(notes: List<Note>): List<RecyclerAdapterView<*>> {
        val rows = mutableListOf<RecyclerAdapterView<*>>()

        rows.add(
            DetailsHeaderRow(
                HeaderViewWithIconBindingModel(
                    JournalSection.JournalNotes.getTitle(),
                    JournalSection.JournalNotes.getDescription(),
                    JournalSection.JournalNotes.getIcon()
                )
            )
        )

        val noteRows = notes.map {
            JournalNotesCard(it)
        }

        rows.addAll(noteRows)

        return rows
    }
}