/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package dk.nsp.mingraviditet.ui.main.journal.sections.sectiondetails.aroundthepregnancy.previouspregnancies

import androidx.hilt.Assisted
import androidx.hilt.lifecycle.ViewModelInject
import androidx.lifecycle.SavedStateHandle
import androidx.lifecycle.ViewModel
import dk.nsp.domain.dataCard.Abortion
import dk.nsp.domain.repository.DataCardRepository
import dk.nsp.mingraviditet.R
import dk.nsp.mingraviditet.ui.adapterviews.EmptyStateFullHeight
import dk.nsp.mingraviditet.ui.adapterviews.TableHeaderRow
import dk.nsp.mingraviditet.ui.adapterviews.TableRow
import dk.nsp.mingraviditet.ui.adapterviews.TableRowBindingModel
import dk.nsp.mingraviditet.ui.main.journal.extensions.toTextModel
import dk.nsp.mingraviditet.util.android.recycler.RecyclerAdapterView
import dk.nsp.mingraviditet.util.extensions.toTextModelOrDefault
import dk.nsp.mingraviditet.util.extensions.transform
import dk.nsp.util.TextModel

class PreviousAbortionsViewModel @ViewModelInject constructor(
    dataCardRepository: DataCardRepository,
    @Assisted private val savedStateHandle: SavedStateHandle
) : ViewModel() {

    val previousAbortions = dataCardRepository.currentDataCard.transform {
        val abortions = it.previousAbortionsSection?.abortions ?: emptyList()
        if (abortions.isNotEmpty()) {
            createRows(abortions)
        } else {
            createEmptyState()
        }
    }

    private fun createRows(previousAbortions: List<Abortion>): List<RecyclerAdapterView<*>> {
        return previousAbortions.mapIndexed { index, abortion ->
            createAbortionSection(index, previousAbortions.size == 1, abortion)
        }.flatten()
    }

    private fun createAbortionSection(
        index: Int,
        singleItem: Boolean,
        abortion: Abortion
    ): List<RecyclerAdapterView<*>> {
        return listOf(
            TableHeaderRow(
                TextModel.from(
                    R.string.journal_section_previous_abortions_abortion_title,
                    TextModel.from(if (singleItem) "" else (index + 1).toString())
                )
            ),
            TableRow(
                TableRowBindingModel(
                    TextModel.from(R.string.journal_section_previous_abortions_abortion_year),
                    abortion.date?.year?.let { TextModel.from(it.toString()) },
                    0,
                    null
                )
            ),
            TableRow(
                TableRowBindingModel(
                    TextModel.from(R.string.journal_section_previous_abortions_abortion_gestation_length),
                    abortion.gestationLength.toTextModel(),
                    1,
                    null
                )
            ),
            TableRow(
                TableRowBindingModel(
                    TextModel.from(R.string.journal_section_previous_abortions_abortion_type),
                    abortion.type.toTextModel(),
                    2,
                    null
                )
            ),
            TableRow(
                TableRowBindingModel(
                    TextModel.from(R.string.journal_section_previous_abortions_abortion_indication),
                    abortion.indication.toTextModelOrDefault(),
                    3,
                    null
                )
            )
        )
    }

    private fun createEmptyState(): List<RecyclerAdapterView<*>> {
        return listOf(
            EmptyStateFullHeight(
                TextModel.from(R.string.journal_section_previous_abortions_empty_state_title),
                TextModel.from(R.string.journal_section_previous_abortions_empty_state_description)
            )
        )
    }
}