package dk.nsp.mingraviditet.ui.main.knowledge.article

import android.os.Bundle
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.fragment.app.Fragment
import androidx.fragment.app.viewModels
import androidx.navigation.fragment.navArgs
import com.commonsense.android.kotlin.system.extensions.onBackPressed
import dagger.hilt.android.AndroidEntryPoint
import dk.nsp.mingraviditet.databinding.FragmentKnowledgeArticleBinding
import dk.nsp.mingraviditet.util.android.recycler.DelegatingListAdapter
import dk.nsp.mingraviditet.util.extensions.observeIfNotHandled

@AndroidEntryPoint
class KnowledgeArticleFragment : Fragment() {

    private val adapter by lazy {
        DelegatingListAdapter()
    }

    private val viewModel by viewModels<KnowledgeArticleViewModel>()

    private val args: KnowledgeArticleFragmentArgs by navArgs()

    override fun onCreateView(
        inflater: LayoutInflater,
        container: ViewGroup?,
        savedInstanceState: Bundle?
    ): View {
        val binding = FragmentKnowledgeArticleBinding.inflate(inflater, container, false)
        binding.toolbar.setNavigationOnClickListener { onBackPressed() }
        binding.toolbar.title = args.article.title

        binding.recyclerView.adapter = adapter

        viewModel.rowsToShow.observe(viewLifecycleOwner) {
            adapter.submitList(it)
        }

        viewModel.scrollToItem.observeIfNotHandled(viewLifecycleOwner) {
            binding.recyclerView.scrollToPosition(it)
        }

        return binding.root
    }
}