package dk.nsp.mingraviditet.ui.main.knowledge.articles

import android.os.Bundle
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.fragment.app.Fragment
import androidx.fragment.app.viewModels
import androidx.navigation.fragment.findNavController
import androidx.navigation.fragment.navArgs
import com.commonsense.android.kotlin.system.extensions.onBackPressed
import dagger.hilt.android.AndroidEntryPoint
import dk.nsp.mingraviditet.databinding.FragmentKnowledgeArticlesBinding
import dk.nsp.mingraviditet.util.android.recycler.DelegatingListAdapter
import dk.nsp.mingraviditet.util.extensions.navigateSafe
import dk.nsp.mingraviditet.util.extensions.observeIfNotHandled

@AndroidEntryPoint
class KnowledgeArticlesFragment : Fragment() {

    private val adapter by lazy {
        DelegatingListAdapter()
    }

    private val args: KnowledgeArticlesFragmentArgs by navArgs()

    private val articlesViewModel: KnowledgeArticlesViewModel by viewModels()

    override fun onCreateView(
        inflater: LayoutInflater,
        container: ViewGroup?,
        savedInstanceState: Bundle?
    ): View {
        val binding = FragmentKnowledgeArticlesBinding.inflate(inflater, null, false)
        binding.toolbar.setNavigationOnClickListener { onBackPressed() }

        binding.recyclerView.adapter = adapter

        binding.toolbar.title = args.category.name

        articlesViewModel.onData.observe(viewLifecycleOwner) {
            adapter.submitList(it) {
                binding.recyclerView.scheduleLayoutAnimation()
            }
        }

        articlesViewModel.onArticleClicked.observeIfNotHandled(viewLifecycleOwner) {
            findNavController().navigateSafe(
                KnowledgeArticlesFragmentDirections.actionKnowledgeArticlesFragmentToKnowledgeArticleFragment(
                    it
                )
            )
        }

        return binding.root
    }
}