package dk.nsp.mingraviditet.ui.main.knowledge.checklist

import android.os.Bundle
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.TextView
import androidx.fragment.app.Fragment
import androidx.fragment.app.viewModels
import androidx.navigation.fragment.navArgs
import com.commonsense.android.kotlin.system.extensions.onBackPressed
import com.commonsense.android.kotlin.views.extensions.visibleOrGone
import com.google.android.material.snackbar.Snackbar
import dagger.hilt.android.AndroidEntryPoint
import dk.nsp.mingraviditet.R
import dk.nsp.mingraviditet.databinding.FragmentChecklistDetailsBinding
import dk.nsp.mingraviditet.domain.ExpandCollapseEnum
import dk.nsp.mingraviditet.util.android.recycler.DelegatingListAdapter
import dk.nsp.mingraviditet.util.extensions.observeIfNotHandled

@AndroidEntryPoint
class ChecklistDetailsFragment : Fragment() {
    private lateinit var binding: FragmentChecklistDetailsBinding

    private val args by navArgs<ChecklistDetailsFragmentArgs>()
    private val viewModel: ChecklistDetailsViewModel by viewModels()

    private val adapter by lazy {
        DelegatingListAdapter()
    }

    override fun onCreateView(
        inflater: LayoutInflater,
        container: ViewGroup?,
        savedInstanceState: Bundle?
    ): View {
        binding = FragmentChecklistDetailsBinding.inflate(inflater, container, false)
        binding.vm = viewModel
        binding.lifecycleOwner = viewLifecycleOwner

        binding.toolbar.setTitle(R.string.checklist_title)
        binding.toolbar.setNavigationOnClickListener { onBackPressed() }

        binding.recyclerView.adapter = adapter

        binding.recyclerView.itemAnimator = null

        val hasDescription = viewModel.checklistHasDescription()
        binding.expandCollapseButton.visibleOrGone(hasDescription)

        //Check if we should show expand/collapse
        binding.description.addOnLayoutChangeListener { view, _, _, _, _, _, _, _, _ ->
            val isMoreThanThreeLines = (view as? TextView)?.lineCount ?: 0 > 3
            binding.expandCollapseButton.visibleOrGone(hasDescription || isMoreThanThreeLines)
        }

        viewModel.onExpandCollapse.observe(viewLifecycleOwner) { expandCollapseEnum ->
            when (expandCollapseEnum) {
                ExpandCollapseEnum.Expanded -> {
                    binding.description.maxLines = Int.MAX_VALUE
                    binding.expandCollapseButton.setText(R.string.common_cta_collapse)
                }
                ExpandCollapseEnum.Collapsed -> {
                    binding.description.maxLines = 3
                    binding.expandCollapseButton.setText(R.string.common_cta_expand)
                }
                else -> {
                }
            }
        }

        viewModel.checklist.observe(viewLifecycleOwner) {
            binding.progressCircular.setPercentage(it.completeness().toInt())
        }

        viewModel.checklistAdapterViews.observe(viewLifecycleOwner) {
            adapter.submitList(it)
        }

        viewModel.onError.observeIfNotHandled(viewLifecycleOwner) {
            Snackbar.make(binding.root, it, Snackbar.LENGTH_LONG)
                .setAction(R.string.common_ok) {}
                .show()
        }

        return binding.root
    }
}