package dk.nsp.mingraviditet.ui.main.more

import android.content.Intent
import android.os.Bundle
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.constraintlayout.motion.widget.MotionLayout
import androidx.fragment.app.Fragment
import androidx.fragment.app.viewModels
import androidx.recyclerview.widget.LinearLayoutManager
import androidx.recyclerview.widget.RecyclerView
import com.commonsense.android.kotlin.views.extensions.setup
import dagger.hilt.android.AndroidEntryPoint
import dk.nsp.mingraviditet.R
import dk.nsp.mingraviditet.databinding.FragmentMoreBinding
import dk.nsp.mingraviditet.ui.adapterviews.EmptyStateRow
import dk.nsp.mingraviditet.ui.useradmission.UserAdmissionActivity
import dk.nsp.mingraviditet.util.android.motionlayout.MotionLayoutStateEnum
import dk.nsp.mingraviditet.util.android.recycler.DelegatingListAdapter
import dk.nsp.mingraviditet.util.extensions.handleToolbarState
import dk.nsp.mingraviditet.util.extensions.setupToolbarStateListener

@AndroidEntryPoint
class MoreFragment : Fragment() {
    private lateinit var binding: FragmentMoreBinding

    private val adapter by lazy {
        DelegatingListAdapter()
    }

    private val moreViewModel: MoreFragmentViewModel by viewModels()

    private var state: MotionLayoutStateEnum = MotionLayoutStateEnum.Start
        set(value) {
            field = value
            (binding.root as MotionLayout).handleToolbarState(value)
        }

    override fun onCreateView(
        inflater: LayoutInflater,
        container: ViewGroup?,
        savedInstanceState: Bundle?
    ): View {
        binding = FragmentMoreBinding.inflate(inflater, null, false)
        binding.toolbarTitle.setText(R.string.bottom_navigation_title_more)
        setupToolbarState()

        binding.recyclerview.setup(
            adapter,
            LinearLayoutManager(context, RecyclerView.VERTICAL, false)
        )

        adapter.submitList(listOf(EmptyStateRow()))

        binding.logout.setOnClickListener {
            moreViewModel.logout()

            startActivity(Intent(requireActivity(), UserAdmissionActivity::class.java))
            activity?.finishAffinity()
        }

        binding.removeConsent.setOnClickListener {
            moreViewModel.removeConsent()

            startActivity(Intent(requireActivity(), UserAdmissionActivity::class.java))
            activity?.finishAffinity()
        }

        return binding.root
    }

    private fun setupToolbarState() {
        setupToolbarStateListener(binding.root) { newState ->
            state = newState
        }

        (binding.root as MotionLayout).handleToolbarState(state)
    }
}