/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package dk.nsp.mingraviditet.ui.main.overview

import androidx.hilt.Assisted
import androidx.hilt.lifecycle.ViewModelInject
import androidx.lifecycle.MutableLiveData
import androidx.lifecycle.SavedStateHandle
import androidx.lifecycle.ViewModel
import androidx.lifecycle.viewModelScope
import com.commonsense.android.kotlin.base.extensions.coroutines.launchIO
import dk.nsp.domain.dataCard.MaternityDataCard
import dk.nsp.domain.repository.DataCardRepository
import dk.nsp.domain.repository.DictionaryRepository
import dk.nsp.shared.Failed
import dk.nsp.shared.Success
import kotlinx.coroutines.async
import kotlinx.coroutines.supervisorScope
import timber.log.Timber

class OverviewFragmentViewModel @ViewModelInject constructor(
    private val dataCardRepository: DataCardRepository,
    private val dictionaryRepository: DictionaryRepository,
    @Assisted private val savedStateHandle: SavedStateHandle
) : ViewModel() {

    val dataCards: MutableLiveData<List<MaternityDataCard>> = MutableLiveData()

    init {
        viewModelScope.launchIO {
            supervisorScope {
                val dataCardRequest = async { dataCardRepository.getDataCards(this).await() }
                val dictionaryRequest = async { dictionaryRepository.getDictionary(this) }

                when (val dataCardRes = dataCardRequest.await()) {
                    is Success -> {
                        Timber.d("Got data card")
                        dataCards.postValue(dataCardRes.value)
                    }
                    is Failed -> {
                        Timber.e(dataCardRes.error)
                    }
                }

                val dictionaryRes = dictionaryRequest.await()
                Timber.d("Dictionary: $dictionaryRes")
            }
        }
    }
}