package dk.nsp.mingraviditet.ui.useradmission.onboarding

import android.os.Build
import android.os.Bundle
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.view.WindowInsets
import androidx.core.view.ViewCompat
import androidx.fragment.app.Fragment
import androidx.navigation.fragment.findNavController
import com.google.android.material.tabs.TabLayoutMediator
import dk.nsp.mingraviditet.databinding.FragmentOnboardingBinding
import dk.nsp.mingraviditet.util.extensions.navigateSafe

class OnboardingFragment : Fragment() {

    private val adapter by lazy {
        OnboardingPageAdapter()
    }

    override fun onCreateView(
        inflater: LayoutInflater,
        container: ViewGroup?,
        savedInstanceState: Bundle?
    ): View {
        val binding = FragmentOnboardingBinding.inflate(inflater, container, false)

        binding.onboardingViewPager.adapter = adapter

        // Set up indicators
        TabLayoutMediator(binding.tabLayout, binding.onboardingViewPager) { _, _ -> }.attach()

        binding.nemidButton.setOnClickListener {
            findNavController().navigateSafe(OnboardingFragmentDirections.actionOnboardingFragmentToAgreementBottomSheetDialog())
        }

        binding.getStartedButton.setOnClickListener {
            findNavController().navigateSafe(OnboardingFragmentDirections.actionOnboardingFragmentToKnowledgeNoLoginActivity())
        }

        ViewCompat.setOnApplyWindowInsetsListener(binding.root) { v, insets ->
            val params: ViewGroup.MarginLayoutParams =
                v.layoutParams as ViewGroup.MarginLayoutParams

            if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.R) {
                val navInsets = insets.getInsets(WindowInsets.Type.navigationBars())
                params.bottomMargin = navInsets.bottom
            } else {
                params.bottomMargin = insets.systemWindowInsetBottom
            }

            insets
        }

        return binding.root
    }
}