package dk.nsp.mingraviditet.ui.widgets

import androidx.databinding.ObservableField
import androidx.lifecycle.ViewModel
import dk.nsp.mingraviditet.R

enum class CheckboxMode {
    Checked, Unchecked, Loading;

    fun getBackground(): Int? {
        return when (this) {
            Checked -> R.drawable.checkbox_checked_with_drawable
            Unchecked -> R.drawable.checkbox_unchecked
            Loading -> null
        }
    }
}

class AsyncCheckBoxViewModel : ViewModel() {

    private val _currentMode: ObservableField<CheckboxMode> =
        ObservableField<CheckboxMode>(CheckboxMode.Unchecked)

    val currentMode: ObservableField<CheckboxMode> = _currentMode

    var onModeChanged: ((CheckboxMode) -> Unit)? = null

    fun setChecked(checked: Boolean) {
        when (checked) {
            true -> _currentMode.set(CheckboxMode.Checked)
            false -> _currentMode.set(CheckboxMode.Unchecked)
        }
    }

    fun onCheckedToggle() {
        val checked = _currentMode.get() ?: CheckboxMode.Unchecked

        _currentMode.set(CheckboxMode.Loading)

        when (checked) {
            CheckboxMode.Checked -> {
                onModeChanged?.invoke(CheckboxMode.Unchecked)
            }
            CheckboxMode.Unchecked -> {
                onModeChanged?.invoke(CheckboxMode.Checked)
            }
            else -> {
            }
        }

    }
}