package dk.nsp.mingraviditet.ui.widgets

import android.graphics.Color
import android.os.Bundle
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.coordinatorlayout.widget.CoordinatorLayout
import com.google.android.material.bottomsheet.BottomSheetBehavior
import com.google.android.material.bottomsheet.BottomSheetDialogFragment
import dk.nsp.mingraviditet.R
import dk.nsp.mingraviditet.databinding.DefaultBottomSheetBinding
import dk.nsp.mingraviditet.util.extensions.observeIfNotHandled

abstract class DefaultBottomSheetDialog : BottomSheetDialogFragment() {
    val binding: DefaultBottomSheetBinding by lazy {
        DefaultBottomSheetBinding.inflate(LayoutInflater.from(context), null, false)
    }

    abstract val viewModel: BottomSheetViewModel

    protected open val forceFullscreen: Boolean = false

    fun addToScrollView(view: View) {
        binding.scrollView.addView(view)
    }

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)

        setStyle(STYLE_NORMAL, R.style.CustomBottomSheetDialogTheme)

        // If content has scrolled we show a shadow below the header
        binding.scrollView.setOnScrollChangeListener { view, _, _, _, _ ->
            binding.headerLayout.isSelected = view.canScrollVertically(-1)
        }
    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)
        binding.viewModel = viewModel

        viewModel.onClose.observeIfNotHandled(viewLifecycleOwner) {
            dismiss()
        }
    }

    // Open fullscreen
    override fun onStart() {
        super.onStart()

        if (forceFullscreen) {
            if (dialog != null) {
                val bottomSheet = dialog?.findViewById<View>(R.id.design_bottom_sheet)

                (bottomSheet?.layoutParams as? CoordinatorLayout.LayoutParams)?.apply {
                    // Create top margin
                    setMargins(0, resources.getDimensionPixelSize(R.dimen.large_spacing), 0, 0)
                    height = ViewGroup.LayoutParams.MATCH_PARENT
                }
            }

            view?.let {
                it.post {
                    val parent = it.parent as View
                    val params = parent.layoutParams as CoordinatorLayout.LayoutParams
                    val behavior = params.behavior
                    val bottomSheetBehavior = behavior as BottomSheetBehavior<*>?
                    bottomSheetBehavior?.peekHeight = it.measuredHeight
                    (binding.bottomSheet.parent as View).setBackgroundColor(Color.TRANSPARENT)
                }
            }
        }
    }

    override fun onCreateView(
        inflater: LayoutInflater,
        container: ViewGroup?,
        savedInstanceState: Bundle?
    ): View? {
        return binding.root
    }
}