package dk.nsp.mingraviditet.ui.widgets

import android.view.animation.Animation
import android.view.animation.AnimationUtils
import dk.nsp.mingraviditet.R
import dk.nsp.mingraviditet.databinding.ViewPinInputFieldsBinding
import dk.nsp.mingraviditet.util.extensions.bindingadapters.setTextModel
import dk.nsp.util.TextModel

class PinCodeInputDelegate(
    private val binding: ViewPinInputFieldsBinding
) {

    private val animationDelay = 100L

    private val pinCodeBoxes = listOf(
        binding.pinCodeField1,
        binding.pinCodeField2,
        binding.pinCodeField3,
        binding.pinCodeField4
    )

    init {
        updatePins("")
    }

    fun updatePins(pin: String) {
        pinCodeBoxes.forEachIndexed { index, pinField ->
            when {
                index < pin.length -> pinField.updateForState(PinState.Filled, true)
                index == pin.length -> pinField.updateForState(PinState.Highlighted, true)
                else -> pinField.updateForState(PinState.Default, true)
            }
        }
    }

    fun hideAndStartLoading() {
        binding.errorMessage.setTextModel(null)
        pinCodeBoxes.forEach {
            if (it.getState() != PinState.Filled) {
                it.updateForState(PinState.Filled, true)
            }
        }

        pinCodeBoxes.forEachIndexed { index, pinField ->
            pinField.updateForState(
                PinState.Loading,
                true,
                index * animationDelay
            )
        }
    }

    fun animateForError(errorTextModel: TextModel?, endAction: () -> Unit) {
        pinCodeBoxes.forEach { pinField ->
            pinField.updateForState(PinState.Error, true)
        }
        val shake = AnimationUtils.loadAnimation(binding.root.context, R.anim.shake)
        shake.setAnimationListener(object : Animation.AnimationListener {
            override fun onAnimationRepeat(p0: Animation?) {}

            override fun onAnimationStart(p0: Animation?) {}

            override fun onAnimationEnd(p0: Animation?) {
                updatePins("")
                binding.errorMessage.setTextModel(errorTextModel)
                endAction()
            }
        })
        shake.duration = PinInputView.transitionDurationMs.toLong()

        binding.boxContainerWrapper.startAnimation(shake)
    }
}