package dk.nsp.mingraviditet.util

import android.os.Bundle
import kotlin.reflect.KFunction0
import kotlin.reflect.KProperty


///**
// * A delegate for boolean values into a [Bundle].
// *
// * Since using a direct [Bundle] (causes the init to capture the variable, and in android terms,
// * that is null at construction time) we instead use a getter, to retrieve the bundle.
// * @property getArgs [Function0R]<[Bundle]?> the getter of the bundle (eg on a [androidx.fragment.app.Fragment] or [android.app.Activity])
// */
class BundleBooleanDelegate(val getArgs: KFunction0<Bundle?>) {

    operator fun getValue(thisRef: Any?, property: KProperty<*>): Boolean? {
        return getArgs.invoke()?.getBoolean(property.name)
    }

    operator fun setValue(thisRef: Any?, property: KProperty<*>, value: Boolean?) {
        val args = getArgs.invoke()
        if (value == null) {
            args?.remove(property.name)
        } else {
            args?.putBoolean(property.name, value)
        }
    }
}

/**
 * A delegate for boolean values into a [Bundle].
 *
 * Since using a direct [Bundle] (causes the init to capture the variable, and in android terms,
 * that is null at construction time) we instead use a getter, to retrieve the bundle.
 * @property getArgs [Function0R]<[Bundle]?> the getter of the bundle (eg on a [androidx.fragment.app.Fragment] or [android.app.Activity])
 */
class BundleStringDelegate(val getArgs: () -> Bundle?) {

    operator fun getValue(thisRef: Any?, property: KProperty<*>): String? {
        return getArgs.invoke()?.getString(property.name)
    }

    operator fun setValue(thisRef: Any?, property: KProperty<*>, value: String?) {
        val args = getArgs()
        if (value == null) {
            args?.remove(property.name)
        } else {
            args?.putString(property.name, value)
        }
    }
}