package dk.nsp.mingraviditet.util.android

import androidx.lifecycle.ViewModel
import androidx.lifecycle.ViewModelProvider

abstract class BaseViewModelFactory<Vm : ViewModel> : ViewModelProvider.Factory {

    abstract val clz: Class<Vm>

    @Throws(IllegalArgumentException::class)
    override fun <T : ViewModel> create(modelClass: Class<T>): T {
        if (modelClass.isAssignableFrom(clz)) {
            @Suppress("UNCHECKED_CAST") //given the above statement is actually the check itself, and since
            //kotlin nor java can infer that T at this point will be our Vm, then we are to "force" it.
            return create() as T
        } else {
            throw IllegalArgumentException("Unknown ViewModel class: ${modelClass::class.java.simpleName} when creating ${clz.simpleName}")
        }
    }

    abstract fun create(): Vm
}