package dk.nsp.mingraviditet.util.extensions

import androidx.navigation.NavController
import androidx.navigation.NavDirections
import timber.log.Timber


/**
 * Since navigate throws even for "trivial" double clicks and un-timed events, we simply "swallow" it to avoid users experincing crashes that should never happen anyway
 * @receiver [NavController] the navController to call navigate on
 * @param directions [NavDirections] should be the autogenerated ones
 * Logs if it fails. (depending on L.errorLoggers)
 */
fun NavController.navigateSafe(directions: NavDirections) {
    try {
        navigate(directions)
    } catch (e: Exception) {
        Timber.e(e, "NavigationController.navigateSafe")
    }
}