package dk.nsp.mingraviditet.util.livedata

import dk.nsp.mingraviditet.util.commonsense_helpers.SetOnceBool
import dk.nsp.mingraviditet.util.commonsense_helpers.getValue
import dk.nsp.mingraviditet.util.commonsense_helpers.setValue

// As per https://medium.com/androiddevelopers/livedata-with-snackbar-navigation-and-other-events-the-singleliveevent-case-ac2622673150
/**
 * Used as a wrapper for data that is exposed via a LiveData that represents an event.
 */
class SingleEvent<out T>(private val value: T) {
    private var hasBeenHandled: Boolean by SetOnceBool(false)

    /**
     * Returns the wrapped value if it hasn't been handled else returns null
     * @return T? [SingleEvent.value]
     */
    fun getIfNotHandled(): T? {

        return if (hasBeenHandled) {
            null
        } else {
            hasBeenHandled = true
            value
        }
    }

    /**
     * Convenience to peek the value even if it has been handled
     * @return [value]
     */
    fun peekValue() = value
}