package dk.nsp.domain.knowledge

import org.junit.Test


internal class ChecklistTest {

    private val nonCheckedChecklistItems = mutableListOf(
        ChecklistItem("0", "1", null, false),
        ChecklistItem("1", "2", null, false),
        ChecklistItem("2", "3", null, false),
        ChecklistItem("3", "4", null, false)
    )

    private val oneCheckedChecklistItems = mutableListOf(
        ChecklistItem("0", "1", null, true),
        ChecklistItem("1", "2", null, false),
        ChecklistItem("2", "3", null, false),
        ChecklistItem("3", "4", null, false)
    )

    private val sixChecklistItems = mutableListOf(
        ChecklistItem("0", "1", null, true),
        ChecklistItem("1", "2", null, false),
        ChecklistItem("2", "3", null, false),
        ChecklistItem("3", "4", null, false),
        ChecklistItem("4", "4", null, false),
        ChecklistItem("5", "4", null, false)
    )

    private val noCheckItemsInChecklist =
        Checklist("id", "Test Checklist", "Test description", nonCheckedChecklistItems)
    private val oneCheckedItemInChecklist =
        Checklist("id1", "Checklist with one item selected", null, oneCheckedChecklistItems)
    private val sixCheckedItemsInChecklist =
        Checklist("id1", "Checklist with six items", null, sixChecklistItems)

    @Test
    fun completeness() {
        assert(noCheckItemsInChecklist.completeness() == 0f)
        assert(oneCheckedItemInChecklist.completeness() == 25F)
        assert(sixCheckedItemsInChecklist.completeness() == 17F) { "Rounded to ${sixCheckedItemsInChecklist.completeness()}" }
    }


    @Test
    fun completenessAsDivision() {
        assert(noCheckItemsInChecklist.completenessAsDivision() == "0/4")
        assert(oneCheckedItemInChecklist.completenessAsDivision() == "1/4")
        assert(sixCheckedItemsInChecklist.completenessAsDivision() == "1/6")
    }

    @Test
    fun getPercentageAsString() {
        assert(noCheckItemsInChecklist.getPercentageAsString() == "0%")
        assert(oneCheckedItemInChecklist.getPercentageAsString() == "25%")
        assert(sixCheckedItemsInChecklist.getPercentageAsString() == "17%")
    }
}