/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2018 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package dk.nsp.mingraviditet.ui.main.appointments

import dk.nsp.domain.careplan.*
import junit.framework.TestCase
import org.joda.time.DateTime

class CareplanActivitiesExtensionsKtTest : TestCase() {

    private val observations = listOf(
        Observation(
            DateTime().minusWeeks(1),
            listOf(Measurement("65", "kg", "Vægt")),
            "Sygeplejerske",
            "Peter Hansen",
            true,
            "Mor",
            ObservationType.Weight,
            "measurementId"
        )
    )

    private val minimalCareplanActivity = CareplanActivity(
        HealthcareProfessional(null, "Test", "Testesen", "Test Org", null, null, null),
        null,
        "11+2",
        null,
        CareplanStatus.Planned,
        "Test",
        null,
        null,
        null,
        null,
        null,
        "id",
        null,
        null,
        DateTime.now()
    )

    private val filledCareplanActivity = CareplanActivity(
        HealthcareProfessional(null, "Test", "Testesen", "Test Org", "12345678", null, null),
        HealthcareLocation(
            null,
            Address("Hedeager 5", "8200", "Aarhus N"),
            "Hospitalet",
            null,
            null,
            null
        ),
        "11+2",
        CareplanActivityPlannedTime(
            DateTime().withTimeAtStartOfDay().plusDays(2),
            DateTime().withTimeAtStartOfDay().plusDays(2).plusHours(1)
        ),
        CareplanStatus.Planned,
        "Test",
        "Description",
        null,
        null,
        null,
        null,
        "id",
        null,
        null,
        DateTime.now()
    )

    fun testGetDateString() {
//        assertEquals(minimalCareplanActivity.getDateString().getString(), )
    }

    fun testGetTimeString() {
        assertEquals(null, minimalCareplanActivity.getTimeString())
//        assertEquals(filledCareplanActivity.getTimeString())
    }

    fun testGetLocation() {
        assertEquals(null, minimalCareplanActivity.getLocationLong())
        assertEquals("Hospitalet\nHedeager 5\n8200 Aarhus N", filledCareplanActivity.getLocationLong())
    }

    fun testGetPractitionerInformation() {
        assertEquals(
            "Test Testesen",
            minimalCareplanActivity.getPractitionerInformation()

        )
        assertEquals("Test Testesen", filledCareplanActivity.getPractitionerInformation())
    }

    fun testHasContactInformation() {
        assertEquals(
            "Shouldn't have any contact info",
            false,
            minimalCareplanActivity.hasContactInformation()
        )
        assertEquals(
            "Should have contact info",
            true,
            filledCareplanActivity.hasContactInformation()
        )
    }

    fun testHasObservationsOrNotes() {
        val emptyNotes = listOf<Note>()
        val emptyObservations = listOf<Observation>()

        val careplanWithEmptyObservationsAndNotes =
            minimalCareplanActivity.copy(notes = emptyNotes, observations = emptyObservations)

        assertEquals(false, careplanWithEmptyObservationsAndNotes.hasObservationsOrNotes())

        assertEquals(
            true,
            filledCareplanActivity.copy(observations = observations).hasObservationsOrNotes()
        )
    }
}
