/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package dk.nsp.mingraviditet.ui.main.journal.sections.sectiondetails.helpers.screenings

import dk.nsp.domain.dataCard.MaternalRhDAntibodyScreeningSection
import dk.nsp.domain.dataCard.PositiveNegativeType
import dk.nsp.mingraviditet.ui.main.journal.sections.sectiondetails.screenings.hasMaternalAntibodyInWeek25IfRhesusNegative
import org.junit.Assert.assertEquals
import org.junit.Test


class ScreeningsBllKtTest {

    @Test
    fun hasMaternalAntibodyInWeek25IfRhesusNegative() {
        //These shouldn't even exist, but if they somehow get created we test them too..
        val rhesusPositiveAntiBodyPositive = MaternalRhDAntibodyScreeningSection(
            null,
            null,
            null,
            PositiveNegativeType.Positive,
            PositiveNegativeType.Positive
        )
        val rhesusPositiveAntiBodyNegative = MaternalRhDAntibodyScreeningSection(
            null,
            null,
            null,
            PositiveNegativeType.Positive,
            PositiveNegativeType.Positive
        )

        // Actual values, that should be expected in real life
        val rhesusNegativeAntiBodyNegative = MaternalRhDAntibodyScreeningSection(
            null,
            null,
            null,
            PositiveNegativeType.Negative,
            PositiveNegativeType.Negative
        )
        val rhesusNegativeAntiBodyPositive = MaternalRhDAntibodyScreeningSection(
            null,
            null,
            null,
            PositiveNegativeType.Negative,
            PositiveNegativeType.Positive
        )

        assertEquals(
            null,
            rhesusPositiveAntiBodyPositive.hasMaternalAntibodyInWeek25IfRhesusNegative()
        )
        assertEquals(
            null,
            rhesusPositiveAntiBodyNegative.hasMaternalAntibodyInWeek25IfRhesusNegative()
        )
        assertEquals(
            PositiveNegativeType.Negative,
            rhesusNegativeAntiBodyNegative.hasMaternalAntibodyInWeek25IfRhesusNegative()
        )
        assertEquals(
            PositiveNegativeType.Positive,
            rhesusNegativeAntiBodyPositive.hasMaternalAntibodyInWeek25IfRhesusNegative()
        )
    }
}