package dk.nsp.domain.auth

import android.security.keystore.KeyGenParameterSpec
import android.security.keystore.KeyProperties
import java.security.KeyStore
import java.security.NoSuchAlgorithmException
import java.security.NoSuchProviderException
import javax.crypto.Cipher
import javax.crypto.KeyGenerator
import javax.crypto.NoSuchPaddingException

const val keyStoreName = "AndroidKeyStore"

class BiometricsHelper {

    @Throws(NoSuchAlgorithmException::class, NoSuchPaddingException::class)
    fun createKeyStoreCipher(): Cipher = Cipher.getInstance(getAesAlgorithm())

    private fun getAesAlgorithm(): String {
        return "${KeyProperties.KEY_ALGORITHM_AES}/${KeyProperties.BLOCK_MODE_CBC}/${KeyProperties.ENCRYPTION_PADDING_PKCS7}"
    }

    @Throws(Exception::class)
    fun getKeystore(): KeyStore {
        val store = KeyStore.getInstance(keyStoreName)
        store.load(null)
        return store
    }

    @Throws(Exception::class)
    fun createCipherKeyGenerator(): KeyGenerator {
        try {
            val cipherKeyGenerator =
                KeyGenerator.getInstance(KeyProperties.KEY_ALGORITHM_AES, keyStoreName)
            val keyProperties = KeyProperties.PURPOSE_ENCRYPT or KeyProperties.PURPOSE_DECRYPT

            val builder = KeyGenParameterSpec.Builder("alias", keyProperties)
                .setBlockModes(KeyProperties.BLOCK_MODE_CBC)
                .setUserAuthenticationRequired(true)
                .setEncryptionPaddings(KeyProperties.ENCRYPTION_PADDING_PKCS7)

            cipherKeyGenerator.init(builder.build())
            return cipherKeyGenerator
        } catch (e: Exception) {
            throw when (e) {
                is NoSuchAlgorithmException,
                is NoSuchProviderException ->
                    Exception("Failed to get instance of KeyGenerator", e)
                else -> e
            }
        }
    }

    companion object {
        private var instance: BiometricsHelper? = null

        fun get(): BiometricsHelper = instance
            ?: BiometricsHelper().apply {
                instance = this
            }
    }
}