package dk.nsp.domain.auth

import dk.nsp.api.util.isHttpErrorWithCode
import dk.nsp.api.util.networkErrorsApi
import dk.nsp.domain.bll.isRefreshTokenExpired
import dk.nsp.domain.bll.networkErrors

inline class ThrowableLoginErrors(val throwable: Throwable)

inline val Throwable.loginErrors: ThrowableLoginErrors
    get() = ThrowableLoginErrors(this)

fun ThrowableLoginErrors.isHttpErrorWithCode(code: Int): Boolean {
    return throwable.networkErrorsApi.isHttpErrorWithCode(code)
}
/**
 * User has entered a bad pin
 * @receiver ThrowableNetworkErrors
 * @return Boolean
 */
fun ThrowableLoginErrors.isBadPin(): Boolean {
    return throwable.loginErrors.isHttpErrorWithCode(401)
}

/**
 * Key is locked serverside, requires relogin
 * @receiver ThrowableNetworkErrors
 */
fun ThrowableLoginErrors.isKeyLocked(): Boolean {
    return throwable.loginErrors.isHttpErrorWithCode(403)
}

/**
 * Key couldn't be found
 * @receiver ThrowableNetworkErrors
 */
fun ThrowableLoginErrors.keyNotFound(): Boolean {
    return throwable.loginErrors.isHttpErrorWithCode(404)
}

fun ThrowableLoginErrors.couldNotCreateKey(): Boolean {
    return throwable.loginErrors.isHttpErrorWithCode(500)
}
fun ThrowableLoginErrors.isRefreshTokenExpired(): Boolean {
    return throwable.networkErrors.isRefreshTokenExpired()
}