/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2018 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package dk.nsp.domain.careplan

import android.os.Parcelable
import dk.nsp.api.careplan.models.CareplanActivityDTO
import kotlinx.parcelize.Parcelize
import org.joda.time.DateTime

@Parcelize
data class CareplanActivity(
    val practitioner: HealthcareProfessional?,
    val location: HealthcareLocation?,
    val gestationWeek: String, //pattern: ^[1-9]?[0-9]\+[0-6]$
    val plannedTime: CareplanActivityPlannedTime?,
    val status: CareplanStatus,
    val title: String,
    val description: String?,
    val reference: String?,
    val goal: CareplanGoal?,
    val code: Code?,
    val kind: String?,
    val id: String,
    val notes: List<Note>?,
    val observations: List<Observation>?,
    val sortDate: DateTime
) : Parcelable

fun CareplanActivityDTO.toDomainModel(): CareplanActivity {
    return CareplanActivity(
        practitioner?.toDomainModel(),
        location?.toDomainModel(),
        gestationWeek,
        plannedTime?.toDomainModel(),
        status.toDomainModel(),
        title,
        description,
        reference,
        goal?.toDomainModel(),
        code?.toDomainModel(),
        kind,
        id,
        notes?.map { it.toDomainModel() },
        observations?.map { it.toDomainModel() },
        sortDate
    )
}