/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package dk.nsp.domain.dataCard

import android.os.Parcelable
import dk.nsp.api.datacard.models.*
import kotlinx.parcelize.Parcelize
import org.joda.time.DateTime

@Parcelize
data class Birth(
    val children: List<Child>?,
    val date: DateTime?,
    val gestationLength: Duration.DurationInDays?,
    val birthPlace: String?,
    val pregnancySummary: String?,
    val birthSummary: String?,
    val subjectiveBirthExperience: SubjectiveBirthExperience?,
    val puerperalSepsis: Boolean?,
) : Parcelable

fun BirthDTO.toDomainModel(): Birth {
    return Birth(
        children?.map { it.toDomainModel() },
        date,
        gestationLength?.toDomainModel(),
        birthPlace,
        pregnancySummary,
        birthSummary,
        subjectiveBirthExperience?.toDomainModel(),
        puerperalSepsis
    )
}

@Parcelize
data class Child(
    val sex: Sex?,
    val birthWeight: BodyMeasureValue?,
    val outcome: BirthOutcome?,
    val childsCurrentHealthStatus: String?
) : Parcelable

fun ChildDTO.toDomainModel(): Child {
    return Child(
        sex?.toDomainModel(),
        birthWeight?.toDomainModel(),
        outcome?.toDomainModel(),
        childsCurrentHealthStatus
    )
}

enum class SubjectiveBirthExperience {
    Good,
    Normal,
    Bad,
}

fun SubjectiveBirthExperienceDTO.toDomainModel(): SubjectiveBirthExperience {
    return when (this) {
        SubjectiveBirthExperienceDTO.Good -> SubjectiveBirthExperience.Good
        SubjectiveBirthExperienceDTO.Normal -> SubjectiveBirthExperience.Normal
        SubjectiveBirthExperienceDTO.Bad -> SubjectiveBirthExperience.Bad
    }
}

enum class Sex {
    Female,
    Male
}

fun SexDTO.toDomainModel(): Sex {
    return when (this) {
        SexDTO.Female -> Sex.Female
        SexDTO.Male -> Sex.Male
    }
}

enum class BirthOutcome {
    Livebirth,
    Stillbirth
}

fun BirthOutcomeDTO.toDomainModel(): BirthOutcome {
    return when (this) {
        BirthOutcomeDTO.Livebirth -> BirthOutcome.Livebirth
        BirthOutcomeDTO.Stillbirth -> BirthOutcome.Stillbirth
    }
}