/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
@file:UseSerializers(DateTimeSerializer::class)

package dk.nsp.domain.dataCard

import android.os.Parcelable
import dk.nsp.api.datacard.models.DurationDTO
import dk.nsp.api.util.converters.DateTimeSerializer
import kotlinx.parcelize.Parcelize
import kotlinx.serialization.UseSerializers
import org.joda.time.DateTime


sealed class Duration : Parcelable {
    @Parcelize
    data class DurationInDays(
        val value: Int,
        val unit: String
    ) : Duration(), Parcelable

    @Parcelize
    data class DurationFromDates(
        val start: DateTime?,
        val end: DateTime?,
        val calculated: DurationInDays?
    ) : Duration(), Parcelable
}

fun DurationDTO.DurationInDaysDTO.toDomainModel(): Duration.DurationInDays {
    return Duration.DurationInDays(value, unit)
}

fun DurationDTO.toDomainModel(): Duration {
    return when (this) {
        is DurationDTO.DurationInDaysDTO -> Duration.DurationInDays(value, unit)
        is DurationDTO.DurationFromDatesDTO -> Duration.DurationFromDates(
            start,
            end,
            calculated?.toDomainModel()
        )
    }
}

