/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.domain.dataCard

import android.os.Parcelable
import dk.nsp.api.datacard.models.MaternityDataCardDTO
import kotlinx.parcelize.Parcelize
import org.joda.time.DateTime

@Parcelize
data class MaternityDataCard(
    val modifiedTime: DateTime?,
    val author: HealthCareActor,
    val recordTarget: CprIdentifiedPerson,
    val childPartnerSection: ChildPartnerSection?,
    val languageSection: LanguageSection?,
    val bodyMeasuresSection: BodyMeasuresSection?,
    val socialHistorySection: SocialHistorySection?,
    val previousBirthsSection: PreviousBirthsSection?,
    val previousAbortionsSection: PreviousAbortionsSection?,
    val expectedDateOfDeliverySection: ExpectedDateOfDeliverySection?,
    val prenatalRiskAssessmentSection: PrenatalRiskAssessmentSection?,
    val workEnvironmentImpactSection: WorkEnvironmentImpactSection?,
    val allergiesSection: AllergiesSection?,
    val screeningsSection: ScreeningsSection?,
    val chronicDiseasesSection: ChronicDiseasesSection?,
    val medicineSection: MedicineSection?,
    val mmrVacinationSection: MmrVaccinationSection?,
    val historyOfPreviousTreatmentWithImpactOnPregnancySection: String?,//TODO HistoryOfPreviousTreatmentWithImpactOnPregnancySection?,
    val tobaccoUseAndExposureSection: TobaccoUseAndExposureSection?,
    val alcoholDrinkingBehaviorSection: AlcoholDrinkingBehaviorSection?,
    val assistedFertilizationSection: AssistedFertilizationSection?,
    val substanceUseSection: SubstanceUseSection?,
    val dietaryAndExerciseSection: DietaryAndExerciseSection?,
    val healthInsuranceSection: HealthInsuranceSection?,
    val birthPlaceSection: BirthPlaceSection?,
    val midwifeClinicSection: MidwifeClinicSection?,
    val postpartumNursingSection: PostpartumNursingSection?,
    val overallAssessmentSection: OverallAssessmentSection?,
    val personalDataSection: PersonalDataSection?,
    val healthCareSection: HealthCareSection?,
    val episodeOfCareIdentifier: String,
    val identifier: String?
) : Parcelable

fun MaternityDataCardDTO.toDomainModel(): MaternityDataCard {
    return MaternityDataCard(
        modifiedTime,
        author.toDomainModel(),
        recordTarget.toDomainModel(),
        childPartnerSection?.toDomainModel(),
        languageSection?.toDomainModel(),
        bodyMeasuresSection?.toDomainModel(),
        socialHistorySection?.toDomainModel(),
        previousBirthsSection?.toDomainModel(),
        previousAbortionsSection?.toDomainModel(),
        expectedDateOfDeliverySection?.toDomainModel(),
        prenatalRiskAssessmentSection?.toDomainModel(),
        workEnvironmentImpactSection?.toDomainModel(),
        allergiesSection?.toDomainModel(),
        screeningsSection?.toDomainModel(),
        chronicDiseasesSection?.toDomainModel(),
        medicineSection?.toDomainModel(),
        mmrVaccinationSection?.toDomainModel(),
        historyOfPreviousTreatmentWithImpactOnPregnancySection, //TODO Fix this when BE returns model
        tobaccoUseAndExposureSection?.toDomainModel(),
        alcoholDrinkingBehaviorSection?.toDomainModel(),
        assistedFertilizationSection?.toDomainModel(),
        substanceUseSection?.toDomainModel(),
        dietaryAndExerciseSection?.toDomainModel(),
        healthInsuranceSection?.toDomainModel(),
        birthPlaceSection?.toDomainModel(),
        midwifeClinicSection?.toDomainModel(),
        postpartumNursingSection?.toDomainModel(),
        overallAssessmentSection?.toDomainModel(),
        personalDataSection?.toDomainModel(),
        healthCareSection?.toDomainModel(),
        episodeOfCareIdentifier,
        documentUniqueId
    )
}