/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package dk.nsp.domain.dataCard

import android.os.Parcelable
import dk.nsp.api.datacard.models.ScreeningsSectionDTO
import kotlinx.parcelize.Parcelize

@Parcelize
data class ScreeningsSection(
    val hepatitisB: PositiveNegativeDeclinedScreeningWithDateSection?,
    val hiv: PositiveNegativeDeclinedScreeningWithDateSection?,
    val syphilis: PositiveNegativeDeclinedScreeningWithDateSection?,
    val chlamydia: PositiveNegativeScreeningWithDateSection?,
    val gonorrhea: PositiveNegativeScreeningWithDateSection?,
    val streptococcusGroupB: PositiveNegativeScreeningWithDateSection?,
    val hemoglobinopathy: PositiveNegativeScreeningWithDateSection?,
    val vitaminDConsumption: DateValueUnitScreeningSection?,
    val maternalRhDAntibody: MaternalRhDAntibodyScreeningSection?,
    val fetalRhDAntibody: FetalRhDAntibodyScreeningSection?,
    val diabetesWeek18To20: DateValueUnitScreeningSection?,
    val diabetesWeek28To30: DateValueUnitScreeningSection?,
    val diabetesGlycosuria: DateValueUnitScreeningSection?,
    val antiDImmunoglobulinGiven: YesNoDateScreeningSection?,
    val mrsaSwap: YesNoDateScreeningSection?
) : Parcelable

fun ScreeningsSectionDTO.toDomainModel(): ScreeningsSection {
    return ScreeningsSection(
        hepatitisB?.toDomainModel(),
        hiv?.toDomainModel(),
        syphilis?.toDomainModel(),
        chlamydia?.toDomainModel(),
        gonorrhea?.toDomainModel(),
        streptococcusGroupB?.toDomainModel(),
        hemoglobinopathy?.toDomainModel(),
        vitaminDConsumption?.toDomainModel(),
        maternalRhDAntibody?.toDomainModel(),
        fetalRhDAntibody?.toDomainModel(),
        diabetesWeek18To20?.toDomainModel(),
        diabetesWeek28To30?.toDomainModel(),
        diabetesGlycosuria?.toDomainModel(),
        antiDImmunoglobulinGiven?.toDomainModel(),
        mrsaSwap?.toDomainModel()
    )
}