/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package dk.nsp.domain.dataCard

import android.os.Parcelable
import dk.nsp.api.datacard.models.LivingConditionsDTO
import dk.nsp.api.datacard.models.MaritalOrPartnershipStatusDTO
import dk.nsp.api.datacard.models.SocialHistorySectionDTO
import kotlinx.parcelize.Parcelize
import org.joda.time.DateTime

@Parcelize
data class SocialHistorySection(
    val modifiedTime: DateTime?,
    val author: HealthCareActor?,
    val maritalOrPartnershipStatus: MaritalOrPartnershipStatus?,
    val livingConditions: LivingConditions?,
    val partner: Partner?,
    val additionalInfo: String? = null
) : Parcelable

fun SocialHistorySectionDTO.toDomainModel(): SocialHistorySection {
    return SocialHistorySection(
        modifiedTime,
        author?.toDomainModel(),
        maritalOrPartnershipStatus?.toDomainModel(),
        livingConditions?.toDomainModel(),
        partner?.toDomainModel(),
        additionalInfo
    )
}

enum class MaritalOrPartnershipStatus {
    Single,
    Married,
    Separated,
    Divorced,
    Widowed
}

fun MaritalOrPartnershipStatusDTO.toDomainModel(): MaritalOrPartnershipStatus {
    return when (this) {
        MaritalOrPartnershipStatusDTO.Single -> MaritalOrPartnershipStatus.Single
        MaritalOrPartnershipStatusDTO.Married -> MaritalOrPartnershipStatus.Married
        MaritalOrPartnershipStatusDTO.Separated -> MaritalOrPartnershipStatus.Separated
        MaritalOrPartnershipStatusDTO.Divorced -> MaritalOrPartnershipStatus.Divorced
        MaritalOrPartnershipStatusDTO.Widowed -> MaritalOrPartnershipStatus.Widowed
    }
}

enum class LivingConditions {
    Partnership,
    Single,
}

fun LivingConditionsDTO.toDomainModel(): LivingConditions {
    return when (this) {
        LivingConditionsDTO.Partnership -> LivingConditions.Partnership
        LivingConditionsDTO.Single -> LivingConditions.Single
    }
}