package dk.nsp.domain.knowledge

import android.os.Parcelable
import dk.nsp.api.cms.models.ArticleContentSectionDTO
import dk.nsp.api.cms.models.ArticleDTO
import kotlinx.parcelize.Parcelize
import org.joda.time.DateTime

@Parcelize
data class Article(
    val id: Int,
    val title: String,
    val searchOrder: Int?,
    val lastUpdated: DateTime,
    val description: String,
    val sections: List<ArticleContentSection>
) : Parcelable

@Parcelize
data class ArticleContentSection(
    val id: Int,
    val title: String,
    val searchOrder: Int?,
    val content: String,
    val weeks: List<String>?
) : Parcelable


fun ArticleDTO.toDomainModel(): Article {
    return Article(id, title, searchOrder, lastUpdated, description, sections.toDomainModel())
}

fun List<ArticleContentSectionDTO>.toDomainModel(): List<ArticleContentSection> {
    return this.map { ArticleContentSection(it.id, it.title, it.searchOrder, it.content, it.weeks) }
}