package dk.nsp.domain.repository

import android.content.Context
import androidx.lifecycle.LiveData
import androidx.lifecycle.MutableLiveData
import dk.nsp.api.getBackendApiLayer
import dk.nsp.domain.careplan.Careplan
import dk.nsp.domain.careplan.CareplanActivity
import dk.nsp.domain.careplan.toDomainModel
import dk.nsp.shared.ResultWrapper
import dk.nsp.shared.mapSuccess
import dk.nsp.shared.util.asyncDefault
import kotlinx.coroutines.CoroutineScope
import kotlinx.coroutines.Deferred

class CareplanRepository(context: Context) {
    private val careplanController = context.getBackendApiLayer().careplanController

    private val _careplans: MutableLiveData<List<Careplan>> = MutableLiveData()

    private val _selectedCareplan: MutableLiveData<Careplan> = MutableLiveData()
    val selectedCareplan: LiveData<Careplan> = _selectedCareplan

    fun getCareplans(scope: CoroutineScope): Deferred<ResultWrapper<List<Careplan>>> =
        scope.asyncDefault {
            val careplansRes = careplanController.getCareplan(this).await()

            careplansRes.mapSuccess {
                val domain = it.map { it.toDomainModel() }

                _careplans.postValue(domain)

                // TODO Decide which careplan to select first:
                _selectedCareplan.postValue(domain.first())

                domain
            }
        }

    fun getCareplanActivity(activityId: String): CareplanActivity? {
        return _selectedCareplan.value?.activities?.find { it.id == activityId }
    }
}