package dk.nsp.shared

import timber.log.Timber


/**
 * Tries the given operation, and if fails then it logs it and returns null
 * @param title [String]
 * @param message [String]
 * @param logger [LoggingFunctionType]<*>
 * @param throwableAction [EmptyFunctionResult]<T>
 * @return T?
 */
public typealias LoggingFunctionType<T> = (throwable: Throwable) -> T

inline fun <T> tryAndLog(
    title: String = "",
    message: String = "",
    logger: LoggingFunctionType<*> = Timber::e,
    throwableAction: () -> T
): T? {
    return try {
        throwableAction()
    } catch (e: Throwable) {
        logger(e)
        return null
    }
}

/**
 * An exception without any stacktrace thus its a lot cheaper to create than regular exceptions
 */
public class NoStackTraceException(
    message: String
) : Exception(
    message,
    null, // cause
    false, // suppression
    false // write stack trace
)