package dk.nsp.shared.util

import kotlinx.coroutines.*

public typealias CoroutineScopeFunction = suspend CoroutineScope.() -> Unit
public typealias CoroutineScopeFunction0<O> = suspend CoroutineScope.() -> O

/**
 * Same as [async] ([Dispatchers.Default])
 * @receiver [CoroutineScope]
 * @param action suspend [CoroutineScope].() -> T
 * @return [Deferred]<T>
 */
public inline fun <T> CoroutineScope.asyncDefault(
    noinline action: CoroutineScopeFunction0<T>
): Deferred<T> = async(Dispatchers.Default, block = action)

/**
 * same as [async] ([Dispatchers.Main])
 * @receiver [CoroutineScope]
 * @param action suspend [CoroutineScope].() -> T
 * @return [Deferred]<T>
 */
public inline fun <T> CoroutineScope.asyncMain(
    noinline action: CoroutineScopeFunction0<T>
): Deferred<T> = async(Dispatchers.Main, block = action)

/**
 * same as [launch] ([Dispatchers.Default])
 * @receiver [CoroutineScope]
 * @param action suspend [CoroutineScope].() -> [Unit]
 * @return [Job]
 */
public inline fun CoroutineScope.launchDefault(
    noinline action: CoroutineScopeFunction
): Job = launch(Dispatchers.Default, block = action)

/**
 * same as [launch] ([Dispatchers.Main])
 * @receiver [CoroutineScope]
 * @param action suspend [CoroutineScope].() -> [Unit]
 * @return [Job]
 */
public inline fun CoroutineScope.launchMain(
    noinline action: CoroutineScopeFunction
): Job = launch(Dispatchers.Main, block = action)

/**
 * same as [withContext] ([Dispatchers.Default])
 * @receiver [CoroutineScope]
 * @param action suspend [CoroutineScope].() -> T
 * @return T
 */
public suspend fun <T> CoroutineScope.withContextDefault(
    action: CoroutineScopeFunction0<T>
): T = withContext(Dispatchers.Default, action)

/**
 * same as [withContext] ([Dispatchers.Main])
 * @receiver [CoroutineScope]
 * @param action suspend [CoroutineScope].() -> T
 * @return T
 */
public suspend fun <T> CoroutineScope.withContextMain(
    action: CoroutineScopeFunction0<T>
): T = withContext(Dispatchers.Main, action)

